@@ -1,8 +1,9 @@
 #' Get the extent (bounding box) of a spatial object.
 #'
 #' @param x the object from which to derive the extent.
-#' @return A table of the lower left and upper right corner of the extent of
-#'   \code{x}.
+#' @return A tibble of the lower left and upper right corner coordinates of the
+#'   extent of \code{x}. This table two columns (x and y) and two rows (minimum
+#'   and maximum).
 #' @family getters
 #' @name getExtent
 #' @rdname getExtent
@@ -88,21 +89,6 @@ setMethod(f = "getExtent",
           }
 )
 
-# ppp ----
-#' @rdname getExtent
-#' @examples
-#'
-#' getExtent(x = gtPPP)
-#' @export
-setMethod(f = "getExtent",
-          signature = "ppp",
-          definition = function(x){
-            bla <- x
-            tibble(x = c(min(bla$x), max(bla$x)),
-                   y = c(min(bla$y), max(bla$y)))
-          }
-)
-
 # Raster ----
 #' @rdname getExtent
 #' @examples
