@@ -1,8 +1,8 @@
 #' Get the type of a spatial object.
 #'
 #' @param x the object for which to determine the type.
-#' @return A vector of two values giving the general type (vector/raster) and
-#'   the specific type/class of \code{x}.
+#' @return A vector of two values of the geometry type (point/line/polygon/grid)
+#'   and the specific main type/class of \code{x}.
 #' @family getters
 #' @name getType
 #' @rdname getType
@@ -33,16 +33,12 @@ setMethod(f = "getType",
 # geom ----
 #' @rdname getType
 #' @examples
-#' getType(x = gtGeoms$polygon)
+#' getType(x = gtGeoms$point)
 #' @export
 setMethod(f = "getType",
           signature = "geom",
           definition = function(x){
-            if(x@type == "grid"){
-              c("raster", x@type)
-            } else {
-              c("vector", x@type)
-            }
+            c(x@type, x@type)
           }
 )
 
@@ -55,8 +51,15 @@ setMethod(f = "getType",
 setMethod(f = "getType",
           signature = signature("Spatial"),
           definition = function(x){
-            c("vector", class(x)[1])
-
+            theType <- class(x)[1]
+            if(theType %in% c("SpatialPoints", "SpatialPointsDataFrame", "SpatialMultiPoints", "SpatialMultiPointsDataFrame", "SpatialPixels", "SpatialPixelsDataFrame")){
+              geomType <- "point"
+            } else if(theType %in% c("SpatialPolygons", "SpatialPolygonsDataFrame", "SpatialGrid", "SpatialGridDataFrame")){
+              geomType <- "polygon"
+            } else if(theType %in% c("SpatialLines", "SpatialLinesDataFrame")){
+              geomType <- "line"
+            }
+            c(geomType, theType)
           }
 )
 
@@ -70,17 +73,15 @@ setMethod(f = "getType",
 setMethod(f = "getType",
           signature = "sf",
           definition = function(x){
-            c("vector", unique(as.character(st_geometry_type(x))))
-          }
-)
-
-# ppp ----
-#' @rdname getType
-#' @export
-setMethod(f = "getType",
-          signature = "ppp",
-          definition = function(x){
-            c("vector", class(x)[1])
+            theType <- unique(as.character(st_geometry_type(x)))
+            if(theType %in% c("POINT", "MULTIPOINT")){
+              geomType <- "point"
+            } else if(theType %in% c("POLYGON", "MULTIPOLYGON")){
+              geomType <- "polygon"
+            } else if(theType %in% c("LINESTRING", "MULTILINESTRING")){
+              geomType <- "line"
+            }
+            c(geomType, theType)
           }
 )
 
@@ -93,16 +94,19 @@ setMethod(f = "getType",
 setMethod(f = "getType",
           signature = "Raster",
           definition = function(x){
-            c("raster", class(x)[1])
+            c("grid", class(x)[1])
           }
 )
 
 # matrix ----
 #' @rdname getType
+#' @examples
+#'
+#' getType(x = matrix(0, 3, 5))
 #' @export
 setMethod(f = "getType",
           signature = "matrix",
           definition = function(x){
-            c("raster", "matrix")
+            c("grid", "matrix")
           }
 )
\ No newline at end of file
