@@ -2,8 +2,9 @@
 #'
 #' This function creates a random geometry
 #' @param type [\code{character(1)}]\cr Either one of the three main feature
-#'   types \code{"point"}, \code{"line"} or \code{"polygon"}, or more
-#'   specifically one of their subtypes, e.g. \code{"hexagon"}.
+#'   types \code{"point"}, \code{"line"} or \code{"polygon"}, \code{"random"},
+#'   or more specifically one of their subtypes, e.g. \code{"hexagon"} (subtypes
+#'   currently not yet supported).
 #' @param window [\code{data.frame(1)}]\cr in case the reference window deviates
 #'   from the bounding box [0, 1] (minimum and maximum values), specify this
 #'   here.
@@ -12,28 +13,27 @@
 #'   vertices already. If left at \code{NULL} the minimum number of vertices for
 #'   the \code{geom} type, i.e. 1 for \code{point}, 2 for \code{line} and 3 for
 #'   \code{polygon}.
-#' @param ... [various]\cr additional arguments.
+#' @return A \code{geom}.
 #' @family geometry shapes
 #' @examples
-#' input <- matrix(nrow = 100, ncol = 100, data = 0)
-#'
 #' # create a random polygon with five vertices
 #' set.seed(1)
 #' someGeom <- gs_random(type = "polygon", vertices = 5)
 #' visualise(geom = someGeom)
 #'
 #' # in case template is given, this serves as source for the window extent
-#' library(magrittr)
-#' gs_random(template = input) %>%
-#'   visualise(geom = ., new = FALSE, linecol = "red")
+#' visualise(geom = gs_random(), new = FALSE, linecol = "red")
 #' @importFrom stats runif
 #' @export
 
-gs_random <- function(type = "point", window = NULL, vertices = NULL, ...){
+gs_random <- function(type = "point", window = NULL, vertices = NULL){
 
-  theCoices <- c("point", "line", "polygon", "triangle", "rectangle", "square", "hexagon", "random")
-  assertSubset(x = type, choices = theCoices)
-  theWindow <- .testWindow(x = window, ...)
+  theCoices <- c("point", "line", "polygon")
+  assertSubset(x = type, choices = c(theCoices, "random"))
+  if(type == "random"){
+    type <- sample(x = theCoices, size = 1)
+  }
+  theWindow <- .testWindow(x = window)
   assertIntegerish(vertices, any.missing = FALSE, len = 1, null.ok = TRUE)
 
   if(type == "point"){
@@ -73,8 +73,8 @@ gs_random <- function(type = "point", window = NULL, vertices = NULL, ...){
   }
 
   if(is.null(theWindow)){
-    theWindow = tibble(x = c(0, 1, 1, 0, 0),
-                       y = c(0, 0, 1, 1, 0))
+    theWindow = tibble(x = c(0, 1),
+                       y = c(0, 1))
   }
 
   theFeatures <- tibble(fid = unique(anchor$fid), gid = unique(anchor$fid))
@@ -83,10 +83,9 @@ gs_random <- function(type = "point", window = NULL, vertices = NULL, ...){
   theGeom <- new(Class = "geom",
                  type = outType,
                  point = anchor,
-                 feature = list(geometry = theFeatures),
-                 group = list(geometry = theGroups),
+                 feature = theFeatures,
+                 group = theGroups,
                  window = theWindow,
-                 scale = "relative",
                  crs = as.character(NA),
                  history = list(paste0("geometry was created randomly")))
 
