@@ -1,7 +1,7 @@
-#' Reflect \code{geom}s
+#' Reflect geometric objects
 #'
-#' Reflect \code{geom}s across a reflection axis.
-#' @param geom [\code{geom(.)}]\cr the object to reflect.
+#' Reflect geometric objects across a reflection axis.
+#' @param obj [\code{geometric object(1)}]\cr the object to reflect.
 #' @param angle [\code{numeric(1)}]\cr the counter-clockwise angle by which the
 #'   reflection axis shall be rotated (can be negative to rotate clockwise).
 #' @param fid [\code{integerish(.)}]\cr if only a subset of features shall be
@@ -11,49 +11,38 @@
 #' @details The reflection axis is a straight line that goes through the plot
 #'   origin with the given angle, where positive angles open towards the
 #'   positive y-axis and negative angles open up towards the negative y-axis.
-#' @examples
-#' # the original object
-#' coords <- data.frame(x = c(30, 60, 60, 40, 10, 40, 20),
-#'                      y = c(40, 40, 60, 70, 10, 20, 40),
-#'                      fid = c(1, 1, 1, 1, 2, 2, 2))
-#' window <- data.frame(x = c(-80, 80),
-#'                      y = c(-80, 80))
-#' aGeom <- gs_polygon(anchor = coords, window = window)
-#'
-#' # reflect several geoms
-#' visualise(geom = gt_reflect(geom = aGeom, angle = 30))
-#'
-#' # reflect a single geom
-#' visualise(geom = gt_reflect(geom = aGeom, angle = -45, fid = 1))
-#' @return Reflected \code{geom}.
+#' @return \code{geom} of the reflected \code{obj}.
 #' @family geometry tools
-#' @importFrom checkmate assertClass testList testNumeric assert
-#'   assertIntegerish assertLogical
+#' @examples
+#' # reflect several features
+#' visualise(gtGeoms$polygon, linewidth = 3)
+#' newPoly <- gt_reflect(obj = gtGeoms$polygon, angle = 45,
+#'                       update = FALSE)
+#' visualise(newPoly, linecol = "green", new = FALSE)
+#'
+#' # reflect a single feature
+#' visualise(gtGeoms$polygon, linewidth = 3)
+#' newPoly <- gt_reflect(obj = gtGeoms$polygon, angle = 90, fid = 2,
+#'                       update = FALSE)
+#' visualise(newPoly, linecol = "green", new = FALSE)
+#' @importFrom checkmate assertNumeric assertIntegerish assertLogical
 #' @importFrom tibble tibble
 #' @importFrom methods new
 #' @export
 
-gt_reflect <- function(geom = NULL, angle = NULL, fid = NULL, update = TRUE){
+gt_reflect <- function(obj, angle, fid = NULL, update = TRUE){
 
-  assertClass(geom, classes = "geom")
-  angleIsList <- testList(angle, types = "numeric", any.missing = FALSE)
-  angleIsNumeric <- testNumeric(angle, any.missing = FALSE, lower = -360, upper = 360, len = 1)
-  assert(angleIsList, angleIsNumeric)
+  assertNumeric(x = angle, any.missing = FALSE, lower = -360, upper = 360, min.len = 1)
   assertIntegerish(x = fid, any.missing = FALSE, null.ok = TRUE)
   assertLogical(x = update, len = 1, any.missing = FALSE)
 
-  theFeatures <- getFeatures(x = geom)
-  theGroups <- getGroups(x = geom)
-
-  # make list, if it is not yet
-  if(angleIsNumeric){
-    angle <- list(angle)
-  }
-
-  verts <- getPoints(x = geom)
-  ids <- unique(verts$fid)
+  theFeatures <- getFeatures(x = obj)
+  theGroups <- getGroups(x = obj)
+  thePoints <- getPoints(x = obj)
+  theWindow <- getWindow(x = obj)
 
   # identify fids to modify
+  ids <- unique(thePoints$fid)
   existsID <- !is.null(fid)
   if(existsID){
     doReflect <- ids %in% fid
@@ -71,7 +60,7 @@ gt_reflect <- function(geom = NULL, angle = NULL, fid = NULL, update = TRUE){
   # modify vertices
   temp <- NULL
   for(i in seq_along(ids)){
-    tempCoords <- verts[verts$fid == ids[i],]
+    tempCoords <- thePoints[thePoints$fid == ids[i],]
     newCoords <- tempCoords
 
     if(doReflect[i]){
@@ -84,11 +73,10 @@ gt_reflect <- function(geom = NULL, angle = NULL, fid = NULL, update = TRUE){
   }
 
   # update window
-  thewindow <- getWindow(x = geom)
   if(update){
-    window <- .updateWindow(input = temp, window = thewindow)
+    window <- .updateWindow(input = temp, window = theWindow)
   } else {
-    window <- thewindow
+    window <- theWindow
   }
 
   # make history
@@ -100,14 +88,13 @@ gt_reflect <- function(geom = NULL, angle = NULL, fid = NULL, update = TRUE){
 
   # make new geom
   out <- new(Class = "geom",
-             type = getType(x = geom)[2],
+             type = getType(x = obj)[1],
              point = temp,
-             feature = list(geometry = theFeatures),
-             group = list(geometry = theGroups),
+             feature = theFeatures,
+             group = theGroups,
              window = window,
-             scale = geom@scale,
-             crs = getCRS(x = geom),
-             history = c(getHistory(x = geom), list(hist)))
+             crs = getCRS(x = obj),
+             history = c(getHistory(x = obj), list(hist)))
 
   return(out)
 }
