@@ -1,3 +1,4 @@
+library(testthat)
 library(checkmate)
 context("gs_point")
 
@@ -23,7 +24,7 @@ test_that("casting to 'point' works", {
   output <- gs_point(anchor = input)
   expect_class(output, classes = "geom")
   expect_true(output@type == "point")
-  expect_data_frame(output@point, any.missing = FALSE, nrows = 5, ncols = 3)
+  expect_data_frame(output@point, any.missing = FALSE, nrows = 4, ncols = 3)
 
   # from line to point
   input <- gs_line(anchor = coords)
@@ -33,12 +34,3 @@ test_that("casting to 'point' works", {
   expect_data_frame(output@point, any.missing = FALSE, nrows = 4, ncols = 3)
 })
 
-test_that("Error if arguments have wrong value", {
-  coords <- data.frame(x = c(40, 70, 70, 50),
-                       y = c(40, 40, 60, 70),
-                       fid = 1)
-
-  expect_error(gs_point(vertices = 4))
-  expect_error(gs_point(anchor = "bla"))
-  expect_error(gs_point(anchor = coords, vertices = "bla"))
-})
